@@ -10,7 +10,7 @@
 bindir=/opt/lantiq/bin
 
 # check for linux 2.6.x or 3.8.x or 3.10.x
-uname -r | grep -q -e 2.6. -e 3.8. -e 3.10.x
+uname -r | grep -q -e 2.6. -e 3.4. -e 3.8. -e 3.10.
 if [ $? -eq 0 ]; then
     MODEXT=.ko
 fi
