@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -30,7 +30,11 @@ extern "C"
    Max and used CMV message payload size [8 bit]
 */
 #define CMV_MAX_PAYLOAD_8BIT_SIZE      2048
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+#define CMV_USED_PAYLOAD_8BIT_SIZE     260
+#else
 #define CMV_USED_PAYLOAD_8BIT_SIZE     256
+#endif
 
 /**
    Max and used CMV message payload size [16 bit]
@@ -52,6 +56,7 @@ extern "C"
       - CMV index
       - CMV length
 */
+#define CMV_HEADER_32BIT_SIZE    (sizeof(CMV_STD_MESSAGE_HEADER_T) / 4)
 #define CMV_HEADER_16BIT_SIZE    (sizeof(CMV_STD_MESSAGE_HEADER_T) / 2)
 #define CMV_HEADER_8BIT_SIZE     (sizeof(CMV_STD_MESSAGE_HEADER_T))
 
@@ -495,6 +500,8 @@ typedef union cmv_message_all_s
 #define D2H_CMV_MSGID_MODEM_READY         0xFF02
 #define D2H_CMV_MSGID_MODEM_FSM_STATE     0x0002
 
+#define D2H_CMV_MSGID_MODEM_TC_STATUS     0x0E22
+
 #ifdef __cplusplus
 /* extern "C" */
 }
