@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_API_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -54,6 +54,11 @@
 #include "drv_mei_cpe_clear_eoc.h"
 #endif
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+#include "drv_mei_cpe_dbg_streams_common.h"
+#endif /* (MEI_SUPPORT_DEBUG_STREAMS == 1) */
+
+
 /* ==========================================================================
    Global macros - constant definitions
    ========================================================================== */
@@ -67,9 +72,12 @@
 
 /** default startup cfg: max wait time for the MODEM READY online msg (bootmode 7) */
 #define MEI_CFG_DEF_WAIT_FOR_MODEM_READY_BM7_SEC    4000
-/** default startup cfg: max wait time for normal msg responce */
+/** default startup cfg: max wait time for normal msg response */
 #define MEI_CFG_DEF_WAIT_FOR_DEVICE_RESPONCE         2000
 
+#define MEI_DBG_FLAGS_ARC_HALT_MASK                 0x00000001
+#define MEI_DBG_FLAGS_ARC_HALT_RELEASED             0
+
 /*
    Control definitions for the received msg buffer.
 */
@@ -135,28 +143,38 @@
 #if (MEI_DRV_OS_BYTE_ORDER == MEI_DRV_OS_BIG_ENDIAN)
 
 /** Swap the hi/lo 16 bit word (DMA access width) */
-#define SWAP32_DMA_WIDTH_ORDER(x)  ( (((x)&0xFFFF0000)>>16)  \
-                                   | (((x)&0x0000FFFF)<<16) )
+#define SWAP32_DMA_WIDTH_ORDER(x)  ( (((x) & 0xFFFF0000) >> 16)  \
+                                   | (((x) & 0x0000FFFF) << 16) )
 
 /** Swap 32 bit */
-#define SWAP32_BYTE_ORDER(x)  ( (((x)&0xFF000000)>>24) \
-                              | (((x)&0x00FF0000)>>8)  \
-                              | (((x)&0x0000FF00)<<8)  \
-                              | (((x)&0x000000FF)<<24) )
+#define SWAP32_BYTE_ORDER(x)  ( (((x) & 0xFF000000) >> 24) \
+                              | (((x) & 0x00FF0000) >> 8)  \
+                              | (((x) & 0x0000FF00) << 8)  \
+                              | (((x) & 0x000000FF) << 24) )
 
 /** Swap 16 bit */
-#define SWAP16_BYTE_ORDER(x)  ( (((x)&0xFF00)>>8) \
-                              | (((x)&0x00FF)<<8) )
+#define SWAP16_BYTE_ORDER(x)  ( (((x) & 0xFF00) >> 8) \
+                              | (((x) & 0x00FF) << 8) )
 
 
 /* swap a value to little endian */
 #define MEI_SWAP_TO_LITTLE_S(xs)  ((((xs) & 0x00FF) << 8) | \
-                                     (((xs) & 0xFF00) >> 8))
+                                   (((xs) & 0xFF00) >> 8) )
 
 #define MEI_SWAP_TO_LITTLE_L(xl)  ((((xl) & 0x000000ff) << 24) | \
-                                    (((xl) & 0x0000ff00) <<  8) | \
-                                    (((xl) & 0x00ff0000) >>  8) | \
-                                    (((xl) & 0xff000000) >> 24))
+                                   (((xl) & 0x0000ff00) <<  8) | \
+                                   (((xl) & 0x00ff0000) >>  8) | \
+                                   (((xl) & 0xff000000) >> 24) )
+
+/* swap a value to big endian */
+#define MEI_SWAP_TO_BIG_S
+#define MEI_SWAP_TO_BIG_L
+
+#define MEI_LO_WORD_GET(x) (((x) << 16) & 0xFFFF0000)
+#define MEI_HI_WORD_GET(x) ( (x)        & 0x0000FFFF)
+
+#define MEI_MSW_WORD_GET(x) ( (x) & 0x0000FFFF)
+#define MEI_LSW_WORD_GET(x) (((x) & 0xFFFF0000) >> 16)
 
 #else
 
@@ -171,6 +189,21 @@
 #define MEI_SWAP_TO_LITTLE_S
 #define MEI_SWAP_TO_LITTLE_L
 
+/* swap a value to big endian */
+#define MEI_SWAP_TO_BIG_S(xs)  ((((xs) & 0x00FF) << 8) | \
+                                (((xs) & 0xFF00) >> 8) )
+
+#define MEI_SWAP_TO_BIG_L(xl)  ((((xl) & 0x000000ff) << 24) | \
+                                (((xl) & 0x0000ff00) <<  8) | \
+                                (((xl) & 0x00ff0000) >>  8) | \
+                                (((xl) & 0xff000000) >> 24) )
+
+#define MEI_LO_WORD_GET(x) ( (x)        & 0x0000FFFF)
+#define MEI_HI_WORD_GET(x) (((x) << 16) & 0xFFFF0000)
+
+#define MEI_MSW_WORD_GET(x) (((x) & 0xFFFF0000) >> 16)
+#define MEI_LSW_WORD_GET(x) ( (x) & 0x0000FFFF)
+
 #endif      /* #if (MEI_DRV_OS_BYTE_ORDER == MEI_DRV_OS_BIG_ENDIAN) */
 
 
@@ -349,7 +382,23 @@
 #define MEI_DRV_MEI_IF_STATE_SET(pMeiDev, new_meiif_state) \
                         (pMeiDev)->meiDrvCntrl.pMeiIfCntrl->eMeiHwState = new_meiif_state
 
+/** set BAR register type */
+#define MEI_BAR_TYPE_SET(pMeiDevm, barIdx, val) \
+                        (pMeiDev)->fwDl.eBarType[barIdx] = val;
 
+/** get BAR register type */
+#define MEI_BAR_TYPE_GET(pMeiDevm, barIdx) \
+                        (pMeiDev)->fwDl.eBarType[barIdx]
+
+#if (MEI_PREDEF_DBG_BAR == 1)
+/** set BAR register debug addr */
+#define MEI_BAR_DBG_ADDR_SET(pMeiDevm, barIdx, val) \
+                        (pMeiDev)->fwDl.dbgBarAddr[barIdx] = val;
+
+/** get BAR register debug addr */
+#define MEI_BAR_DBG_ADDR_GET(pMeiDevm, barIdx) \
+                        (pMeiDev)->fwDl.dbgBarAddr[barIdx]
+#endif /* (MEI_PREDEF_DBG_BAR == 1) */
 
 /** set the MEI driver state for this channel */
 #define MEI_TRACE_DRV_STATE_CHANGES   0
@@ -514,6 +563,11 @@
 #define MEI_IF_STAT_INC_FWDL_ERR_COUNT(p_dev_struct) \
                               (p_dev_struct)->statistics.fwDlErrCount++
 
+#define MEI_IF_STAT_INC_FWDL_OPT_COUNT_INC(p_dev_struct) \
+                              (p_dev_struct)->statistics.fwDlOptSuccessCount++
+
+#define MEI_IF_STAT_INC_FWDL_OPT_ERR_COUNT(p_dev_struct) \
+                              (p_dev_struct)->statistics.fwDlOptFailedCount++
 
 #define MEI_IF_STAT_INC_SWRST_COUNT(p_dev_struct) \
                               (p_dev_struct)->statistics.drvSwRstCount++
@@ -671,8 +725,9 @@ typedef enum
    /** VR9 (xrx200) */
    e_MEI_DEV_PLATFORM_CONFIG_VR9       = 1,
    /** VR10 (xrx300, smartphy) */
-   e_MEI_DEV_PLATFORM_CONFIG_VR10      = 2
-
+   e_MEI_DEV_PLATFORM_CONFIG_VR10      = 2,
+   /** VR10_320 (xrx320) */
+   e_MEI_DEV_PLATFORM_CONFIG_VR10_320  = 4
 } MEI_DEV_PLATFORM_CONFIG_E;
 
 /* ==========================================================================
@@ -786,6 +841,11 @@ struct MEI_dyn_nfc_data_s
 
 };
 
+/** General callback structure */
+typedef struct MEI_callback_s
+{
+   MEI_InternalTcLayerRequestCallback_t pTcLayerRequestHandler;
+} MEI_CALLBACK_T;
 
 #if (MEI_SUPPORT_DFE_GPA_ACCESS == 1)
 /* For General Purpose Access - message buffer */
@@ -913,8 +973,11 @@ typedef struct MEI_dev_s
    /** dsm vectoring support within firmware */
    MEI_DSM_VECTOR_FW_SUPPORT_MODE_E nFwVectorSupport;
 
-   IOCTL_MEI_firmwareFeatures_t firmwareFeatures;
 #endif /* (MEI_SUPPORT_DSM == 1) */
+   IOCTL_MEI_firmwareFeatures_t firmwareFeatures;
+
+   /** MEI callback set */
+   MEI_CALLBACK_T meiCallback;
 
    /* =======================================================================
       Modem data
@@ -944,6 +1007,11 @@ typedef struct MEI_dev_s
    MEI_DYN_NFC_DATA_T    *pRootNfcRecvFirst;
    MEI_DYN_NFC_DATA_T    *pRootNfcRecvLast;
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+   /** list of all open instances which can receive debug streams */
+   MEI_DYN_DBG_STRM_DATA_T    *pRootDbgStrmRecvFirst;
+   MEI_DYN_DBG_STRM_DATA_T    *pRootDbgStrmRecvLast;
+#endif
 
    /* =======================================================================
       Protection
@@ -970,13 +1038,14 @@ typedef struct MEI_dev_s
 #endif
 } MEI_DEV_T;
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0)) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
 typedef struct MEI_devcfg_data_s
 {
    IFX_uint32_t               nIrq;
    IFX_uint32_t               nBaseAddr;
    struct clk                 *clk;
    MEI_DEV_PLATFORM_CONFIG_E  platform;
+   struct device              *dev;
 } MEI_DEVCFG_DATA_T;
 #endif
 
@@ -1034,7 +1103,7 @@ struct MEIx_cntrl_s
 struct MEI_dyn_cntrl_s
 {
    /** current open instance of this device */
-   IFX_uint8_t          openInstance;
+   IFX_uint8_t         openInstance;
    /** points to the MEIx data struct */
    MEIX_CNTRL_T       *pDfeX;
    /** points to the MEI device data struct */
@@ -1045,9 +1114,15 @@ struct MEI_dyn_cntrl_s
    MEI_DYN_NFC_DATA_T *pInstDynNfc;
    /** device send lock (semaphore)
        - protection against multiple use of the same file descriptor */
-   MEI_DRVOS_sema_t     pInstanceRWlock;
-};
+   MEI_DRVOS_sema_t    pInstanceRWlock;
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+   /** points to the dynamic block for receive msg (open specific) */
+   MEI_DYN_DBG_STRM_DATA_T    *pInstDynDebugStream;
+   /** protection of the control struct and FIFO */
+   MEI_DRVOS_sema_t            dbgStreamLock;
+#endif
+};
 
 /**
    Callback function for check the valid state of a given device
@@ -1068,7 +1143,7 @@ extern IFX_int32_t MEI_IrqProtectCount;
 /** what string */
 extern const char MEI_WHATVERSION[] ;
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0)) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
 /** device tree data */
 extern MEI_DEVCFG_DATA_T MEI_DevCfgData;
 #endif
@@ -1077,16 +1152,24 @@ extern MEI_DEVCFG_DATA_T MEI_DevCfgData;
 MEI_DRV_PRN_USR_MODULE_DECL(MEI_DRV);
 MEI_DRV_PRN_INT_MODULE_DECL(MEI_DRV);
 
-/* MEI CPE-Driver: fw message dump debug module - create print level variable */
+/* MEI CPE-Driver: fw message dump debug module - declare print level variable */
 MEI_DRV_PRN_USR_MODULE_DECL(MEI_MSG_DUMP_API);
 MEI_DRV_PRN_INT_MODULE_DECL(MEI_MSG_DUMP_API);
 
+/* MEI Driver: notifications debug module - declare print level variable */
+MEI_DRV_PRN_USR_MODULE_DECL(MEI_NOTIFICATIONS);
+MEI_DRV_PRN_INT_MODULE_DECL(MEI_NOTIFICATIONS);
+
 /** define the boot mode */
 extern IFX_int32_t  MEI_BlockTimeout;
 extern IFX_uint8_t  MEI_DefDownLoadChipId;
 extern IFX_uint32_t MEI_MaxWaitForModemReady_ms;
 extern IFX_int32_t  MEI_MaxWaitDfeResponce_ms;
 extern IFX_uint32_t MEI_FsmStateSetMsgPreAction;
+extern IFX_int32_t  MEI_DbgFlags;
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+extern IFX_int32_t  MEI_DbgLogger;
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #if (MEI_SUPPORT_VDSL2_ADSL_SWAP == 1)
 extern IFX_uint32_t MEI_fwModeSelect;
@@ -1298,6 +1381,50 @@ extern IFX_int32_t MEI_IoctlPllOffsetConfigGet(
 extern IFX_int32_t MEI_PLL_ConfigInit(MEI_DEV_T *pMeiDev);
 extern IFX_int32_t MEI_PLL_ConfigSet(MEI_DYN_CNTRL_T *pMeiDynCntrl);
 extern IFX_void_t MEI_VRX_ModemStateUpdate(MEI_DYN_CNTRL_T *pMeiDynCntrl);
+
+#if defined(MEI_SUPPORT_DEBUG_STREAMS) && (MEI_SUPPORT_DEBUG_STREAMS == 1)
+extern IFX_int_t MEI_DBG_STREAM_ModuleInit(void);
+
+extern IFX_int_t MEI_DBG_STREAM_ModuleDelete(void);
+
+extern IFX_int_t MEI_DBG_STREAM_ControlRelease(
+                              MEI_DYN_CNTRL_T  *pMeiDynCntrl);
+
+extern IFX_int_t MEI_DBG_STREAM_ControlReset(
+                              MEI_DYN_CNTRL_T  *pMeiDynCntrl);
+
+extern IFX_int_t MEI_DBG_STREAM_FwConfigSet(
+                              MEI_DYN_CNTRL_T  *pMeiDynCntrl);
+
+extern IFX_int_t MEI_IoctlDbgStreamDataGet(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              IOCTL_MEI_DEBUG_STREAM_data_t  *pDbgStreamRead);
+
+extern IFX_int_t MEI_IoctlDbgStreamMaskSet(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              IOCTL_MEI_DEBUG_STREAM_mask_set_t  *pDbgStreamMask);
+
+extern IFX_int_t MEI_IoctlDbgStreamConfigGet(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              IOCTL_MEI_DEBUG_STREAM_configGet_t   *param);
+
+extern IFX_int_t MEI_IoctlDbgStreamConfigSet(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              const IOCTL_MEI_DEBUG_STREAM_configSet_t   *param);
+
+extern IFX_int_t MEI_IoctlDbgStreamRelease(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              const IOCTL_MEI_DEBUG_STREAM_release_t  *param);
+
+extern IFX_int_t MEI_IoctlDbgStreamControl(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              const IOCTL_MEI_DEBUG_STREAM_control_t  *pDbgStreamCntrl);
+
+extern IFX_int_t MEI_IoctlDbgStreamStatisticGet(
+                              MEI_DYN_CNTRL_T          *pMeiDynCntrl,
+                              IOCTL_MEI_DEBUG_STREAM_statistic_t   *pDbgStreamStatistics);
+
+#endif /* (MEI_SUPPORT_DEBUG_STREAMS == 1) */
 /* ==========================================================================
    Extern function definitions from the board driver for debug (trigger)
    ========================================================================== */
@@ -1326,6 +1453,9 @@ extern IFX_void_t MEI_Eb_DfeTriggerRead( IFX_uint8_t  DeviceNum,
 #define MEI_EB_TRIGGER_READ
 #endif      /* #if (MEI_EB_TRIGGER_FCT == 1) */
 
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+extern int MEI_debugLogSend(IFX_char_t *fmt, ...);
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #endif      /* #ifndef _DRV_MEI_CPE_API_H */
 
