@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -34,6 +34,15 @@ typedef struct {
    unsigned int dummy;
 } MEI_XTM_ShowtimeExit_t;
 
+typedef struct {
+   unsigned int request_type;
+   unsigned int is_bonding;
+} MEI_TC_Request_t;
+
+typedef struct {
+   unsigned int reset_type;
+} MEI_TC_Reset_t;
+
 extern IFX_int32_t MEI_InternalXtmSwhowtimeEntrySignal(
                               MEI_DYN_CNTRL_T        *pMeiDynCntrl,
                               MEI_XTM_ShowtimeEnter_t *pArgXtm);
@@ -42,10 +51,18 @@ extern IFX_int32_t MEI_InternalXtmSwhowtimeExitSignal(
                               MEI_DYN_CNTRL_T        *pMeiDynCntrl,
                               MEI_XTM_ShowtimeExit_t *pArgXtm);
 
+extern IFX_int32_t MEI_InternalTcRequest(
+                              MEI_DYN_CNTRL_T        *pMeiDynCntrl,
+                              MEI_TC_Request_t       *pArgTcRequest);
+
+extern IFX_int32_t MEI_InternalTcReset(
+                              MEI_DYN_CNTRL_T        *pMeiDynCntrl,
+                              MEI_TC_Reset_t         *pArgTcReset);
+
 extern int ppa_callback_set(e_ltq_mei_cb_type type, void *func);
 extern void* ppa_callback_get(e_ltq_mei_cb_type type);
 
-int ltq_mei_atm_showtime_check (
+int ltq_mei_showtime_check(
                               const unsigned char line_idx,
                               int *is_showtime,
                               struct port_cell_info *port_cell,
