@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_API_INTERN_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -51,6 +51,8 @@ typedef struct MEI_dyn_cntrl_s    MEI_DYN_CNTRL_T;
 */
 typedef void (*MEI_InternalMsgRecvCallBack)(void *);
 
+typedef IFX_int32_t (*MEI_InternalTcLayerRequestCallback_t) (IFX_int32_t, IFX_uint32_t);
+
 #if (MEI_EXPORT_INTERNAL_API == 1)
 
 /* ==========================================================================
@@ -639,7 +641,7 @@ extern IFX_int32_t MEI_InternalCmdMsgWrite(
       Error:
          -e_MEI_ERR_RETURN_ARG:     cannot return arguments
          -e_MEI_ERR_DEV_NEG_RESP:   negative acknowledge
-         -e_MEI_ERR_DEV_INVAL_RESP: invalid responce.
+         -e_MEI_ERR_DEV_INVAL_RESP: invalid response.
 
    \remarks
       This function should be only used within driver layer, internal access
@@ -1029,6 +1031,20 @@ extern IFX_int32_t MEI_InternalCEocFrameRd(
 
 #endif      /* #if (MEI_DRV_CLEAR_EOC_ENABLE == 1) */
 
+typedef enum
+{
+   e_MEI_CALLBACK_TYPE_TC_LAYER_REQUEST
+} MEI_CALLBACK_TYPE_E;
+
+extern IFX_int32_t MEI_InternalCallbackInit(
+                              MEI_DYN_CNTRL_T *pMeiDynCntrl,
+                              MEI_CALLBACK_TYPE_E eCallbackType);
+
+extern IFX_int32_t MEI_InternalCallbackSet(
+                              MEI_DYN_CNTRL_T *pMeiDynCntrl,
+                              MEI_CALLBACK_TYPE_E eCallbackType,
+                              void *pFunc);
+
 #endif      /* #if (MEI_EXPORT_INTERNAL_API == 1) */
 
 #endif      /* #ifndef _DRV_MEI_CPE_API_INTERN_H */
