@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -61,6 +61,10 @@
 #include "drv_mei_cpe_clear_eoc_common.h"
 #endif
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+#include "drv_mei_cpe_dbg_streams.h"
+#endif
+
 /* ============================================================================
    Local Macros & Definitions
    ========================================================================= */
@@ -96,7 +100,7 @@ IFX_int32_t MEI_IrqProtectCount = MEI_IRQ_PROTECT_COUNT;
 */
 IFX_uint32_t MEI_FsmStateSetMsgPreAction = 0;
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,10,0)) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
 /** device tree data */
 MEI_DEVCFG_DATA_T MEI_DevCfgData;
 #endif
@@ -113,6 +117,10 @@ MEI_DRV_PRN_INT_MODULE_CREATE(MEI_DRV, MEI_DRV_PRN_LEVEL_LOW);
 MEI_DRV_PRN_USR_MODULE_CREATE(MEI_MSG_DUMP_API, MEI_DRV_PRN_LEVEL_LOW);
 MEI_DRV_PRN_INT_MODULE_CREATE(MEI_MSG_DUMP_API, MEI_DRV_PRN_LEVEL_LOW);
 
+/* MEI CPE-Driver: notifications debug module - create print level variable */
+MEI_DRV_PRN_USR_MODULE_CREATE(MEI_NOTIFICATIONS, MEI_DRV_PRN_LEVEL_LOW);
+MEI_DRV_PRN_INT_MODULE_CREATE(MEI_NOTIFICATIONS, MEI_DRV_PRN_LEVEL_LOW);
+
 /* Block timeout (for debugging)
    0: timeout not blocked
    1: timeout blocked
@@ -137,6 +145,17 @@ IFX_uint8_t MEI_DefDownLoadChipId = MEI_DEF_DOWNLOAD_CHIPID;
 IFX_uint32_t MEI_MailboxBase_ME2ARC = MEI_BOOT_MAILBOX_ME2ARC_ADDR;
 IFX_uint32_t MEI_MailboxBase_ARC2ME = MEI_BOOT_MAILBOX_ARC2ME_ADDR;
 
+/* Bitmask, currently used bit 0:
+      0: ARC is released out of HALT after FW download (DEFAULT!)
+      1: ARC is NOT released out of HALT after FW download */
+IFX_int32_t MEI_DbgFlags = 0;
+
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+/* Logger usage:
+      0: Statndart destination is used for debug output (DEFAULT!)
+      1: Logger is used for debug output */
+IFX_int32_t MEI_DbgLogger = 0;
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #if (MEI_SUPPORT_VDSL2_ADSL_SWAP == 1)
 IFX_uint32_t MEI_fwModeSelect  = 0x0;
@@ -248,10 +267,10 @@ MEI_STATIC IFX_int32_t MEI_WaitForFirstResponce(MEI_DEV_T *pMeiDev)
       default:
          /* invalid boot state */
          PRN_ERR_USR_NL( MEI_DRV, MEI_DRV_PRN_LEVEL_ERR,
-                ("MEI_DRV[%02d]: ERROR Wait for device - invalid drv state" MEI_DRV_CRLF,
-                  MEI_DRV_LINENUM_GET(pMeiDev)));
+                ("MEI_DRV[%02d]: ERROR Wait for device - invalid drv state %d" MEI_DRV_CRLF,
+                  MEI_DRV_LINENUM_GET(pMeiDev), MEI_DRV_STATE_GET(pMeiDev)));
 
-         return IFX_ERROR;
+         return -e_MEI_ERR_INVAL_STATE;
    }
 
    return ret;
@@ -353,7 +372,8 @@ MEI_STATIC IFX_void_t MEI_MeiDevCntrlFree(
                         (IFX_uint32_t)sizeof(MEI_MEI_REG_IF_U),
                         (IFX_uint8_t **)&(pMeiDevCntrl->meiIf[portIdx].pVirtMeiRegIf));
                   }
-                  else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+                  else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+                           MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
                   {
                      MEI_VR10_PcieEntityFree(pMeiXCntrl->entityNum);
                   }
@@ -398,7 +418,8 @@ MEIX_CNTRL_T *MEI_DevXCntrlStructAlloc(IFX_uint8_t entityNum)
 {
    MEIX_CNTRL_T  *pXCntrl = NULL;
 
-   if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+   if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+       MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
    {
       if (MEI_VR10_PcieEntitiesCheck(entityNum) != IFX_SUCCESS)
       {
@@ -574,7 +595,8 @@ MEI_DEV_T *MEI_DevLineStructAlloc( IFX_uint8_t nLineNum )
       /* save the device number for downloading firmware*/
       pMeiDev->fwDl.line_num = nLineNum;
 
-      if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+      if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+          MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
       {
          if (MEI_VR10_PcieEntityInit(&pMeiDev->meiDrvCntrl) != IFX_SUCCESS)
          {
@@ -615,7 +637,7 @@ MEI_DEV_T *MEI_DevLineStructAlloc( IFX_uint8_t nLineNum )
 #endif
 
       /* init active members for this device */
-      if(MEI_DRVOS_SelectQueueInit(&pMeiDev->selNfcWakeupList) != IFX_SUCCESS)
+      if(MEI_DRVOS_SelectQueueInit((MEI_DRVOS_selectQueue_t *)&pMeiDev->selNfcWakeupList) != IFX_SUCCESS)
       {
          PRN_ERR_USR_NL( MEI_DRV, MEI_DRV_PRN_LEVEL_ERR,
                ("MEI_DRV[%02d]: ERROR Line Struct Allocate - init driver lock" MEI_DRV_CRLF,
@@ -650,6 +672,7 @@ MEI_DEV_T *MEI_DevLineStructAlloc( IFX_uint8_t nLineNum )
 
 ERR_MEI_DEV_LINE_STRUCT_ALLOC:
 
+   MEI_DRVOS_EventDelete(&pMeiDev->eventMailboxRecv);
    MEI_DRVOS_Free(pMeiDev);
    pMeiDev = IFX_NULL;
 
@@ -708,6 +731,7 @@ IFX_int32_t MEI_DevLineStructFree(IFX_uint8_t nLineNum)
 #if (MEI_DRV_CLEAR_EOC_ENABLE == 1)
          MEI_CEOC_ReleaseDevCntrl(pMeiDev);
 #endif
+
          /*
             clear active members for this device:
             - clear required: driver lock per line
@@ -826,6 +850,10 @@ IFX_int32_t MEI_DynCntrlStructAlloc(
 
    *ppMeiDynCntrl = pDynCntrl;
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+   MEI_DBG_STREAM_ControlReset(pDynCntrl);
+#endif
+
    return IFX_SUCCESS;
 }
 
@@ -847,6 +875,15 @@ IFX_int32_t MEI_DynCntrlStructFree( MEI_DYN_CNTRL_T **ppMeiDynCntrl )
    if (*ppMeiDynCntrl)
    {
       pDynCntrl = *ppMeiDynCntrl;
+
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+         if (pDynCntrl->pInstDynDebugStream)
+         {
+            (void)MEI_DBG_STREAM_ControlRelease(pDynCntrl);
+         }
+         MEI_DRVOS_SemaphoreDelete(&pDynCntrl->dbgStreamLock);
+#endif
+
       *ppMeiDynCntrl = NULL;
 
       pDynCntrl->pInstDynCmd = IFX_NULL;
@@ -934,7 +971,6 @@ IFX_int32_t MEI_InstanceLineAlloc(
    MEI_DEV_T         *pMeiDev = NULL;
    MEI_DYN_CNTRL_T   *pMeiDynCntrl = NULL;
 
-
    /* allocate dynamic data */
    if( MEI_DynCntrlStructAlloc(nLineNum, &pMeiDynCntrl ) != IFX_SUCCESS )
    {
@@ -1133,8 +1169,8 @@ IFX_int32_t MEI_CheckIoctlCmdSendState(
          {
             /* device is still not ready --> block commands */
             PRN_ERR_USR_NL( MEI_DRV, MEI_DRV_PRN_LEVEL_ERR,
-                   ("MEI_DRV[%02d-%02d]: ERROR ioctl - inval state, not ready for send !!!" MEI_DRV_CRLF,
-                    MEI_DRV_LINENUM_GET(pMeiDev), pMeiDynCntrl->openInstance));
+                   ("MEI_DRV[%02d-%02d]: ERROR ioctl - inval state %d, not ready for send !!!" MEI_DRV_CRLF,
+                    MEI_DRV_LINENUM_GET(pMeiDev), pMeiDynCntrl->openInstance, MEI_DRV_STATE_GET(pMeiDev)));
 
             retVal = -e_MEI_ERR_INVAL_STATE;
          }
@@ -1274,7 +1310,7 @@ IFX_int32_t MEI_IoctlDebugLevelSet(
    if ( (pArgDbgLevel->valLevel   >= MEI_DRV_PRN_LEVEL_LOW) &&
         (pArgDbgLevel->valLevel   <= MEI_DRV_PRN_LEVEL_OFF) &&
         (pArgDbgLevel->eDbgModule >= e_MEI_DBGMOD_MEI_DRV)  &&
-        (pArgDbgLevel->eDbgModule <= e_MEI_DBGMOD_MEI_MSG_DUMP_API) )
+        (pArgDbgLevel->eDbgModule <  e_MEI_DBGMOD_LAST) )
    {
       switch(pArgDbgLevel->eDbgModule)
       {
@@ -1288,6 +1324,11 @@ IFX_int32_t MEI_IoctlDebugLevelSet(
             MEI_DRV_PRN_INT_LEVEL_SET(MEI_MSG_DUMP_API, pArgDbgLevel->valLevel);
             break;
 
+         case e_MEI_DBGMOD_MEI_NOTIFICATIONS:
+            MEI_DRV_PRN_USR_LEVEL_SET(MEI_NOTIFICATIONS, pArgDbgLevel->valLevel);
+            MEI_DRV_PRN_INT_LEVEL_SET(MEI_NOTIFICATIONS, pArgDbgLevel->valLevel);
+            break;
+
          default:
             return -e_MEI_ERR_INVAL_ARG;
       }
@@ -1328,7 +1369,8 @@ IFX_void_t MEI_IoctlRequestConfig(
    pArgDevCfg_out->currOpenInst = (unsigned int)pMeiDynCntrl->openInstance;
    pArgDevCfg_out->phyBaseAddr  = (unsigned int)MEI_DRV_MEI_PHY_ADDR_GET(pMeiDev);
    pArgDevCfg_out->virtBaseAddr = (unsigned int)MEI_DRV_MEI_VIRT_ADDR_GET(pMeiDev);
-   if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+   if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+       MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
    {
       pArgDevCfg_out->phyPDBRAMaddr  = (unsigned int)MEI_DRV_PDBRAM_PHY_ADDR_GET(pMeiDev);
       pArgDevCfg_out->virtPDBRAMaddr = (unsigned int)MEI_DRV_PDBRAM_VIRT_ADDR_GET(pMeiDev);
@@ -1598,7 +1640,7 @@ IFX_uint32_t MEI_DefaultInitDevice(
 
 /**
    Start the corresponding device
-   - release reset, unmask interrupts and wait for the first responce.
+   - release reset, unmask interrupts and wait for the first response.
 
 \param
    *pMeiDev  private device data
@@ -1920,23 +1962,24 @@ IFX_int32_t MEI_PollIntPerVrxLine(
    {
       if (pMeiDev->eModePoll == e_MEI_DEV_ACCESS_MODE_ACTIV_POLL)
       {
-         MEI_DRV_GET_UNIQUE_DRIVER_ACCESS(pMeiDev);
+         /* Exclude SMP platforms race contiditions caused driver access lock */
+         /* \TODO: investigate handling */
+         /* MEI_DRV_GET_UNIQUE_DRIVER_ACCESS(pMeiDev); */
          MEI_DRV_GET_UNIQUE_DEVICE_ACCESS(pMeiDev);
-      }
-      else
-      {
-         MEI_DRV_GET_UNIQUE_DEVICE_ACCESS(pMeiDev);
-      }
 
-      meiIntCnt = MEI_ProcessIntPerVrxLine(pMeiDev);
+         meiIntCnt = MEI_ProcessIntPerVrxLine(pMeiDev);
 
-      if (pMeiDev->eModePoll == e_MEI_DEV_ACCESS_MODE_ACTIV_POLL)
-      {
-         MEI_DRV_RELEASE_UNIQUE_DRIVER_ACCESS(pMeiDev);
+         /* Exclude SMP platforms race contiditions caused driver access lock */
+         /* \TODO: investigate handling */
+         /* MEI_DRV_RELEASE_UNIQUE_DRIVER_ACCESS(pMeiDev); */
          MEI_DRV_RELEASE_UNIQUE_DEVICE_ACCESS(pMeiDev);
       }
       else
       {
+         MEI_DRV_GET_UNIQUE_DEVICE_ACCESS(pMeiDev);
+
+         meiIntCnt = MEI_ProcessIntPerVrxLine(pMeiDev);
+
          MEI_DRV_RELEASE_UNIQUE_DEVICE_ACCESS(pMeiDev);
       }
    }
@@ -1960,7 +2003,7 @@ IFX_int32_t MEI_ProcessIntPerVrxLine(
    IFX_int32_t  processCnt = 0, gpIntCnt = 0;
    MEI_MeiRegVal_t processInt, intMask, tmpInt;
 #if (MEI_DBG_DSM_PROFILING == 1)
-   IFX_uint32_t *pMeiErrVecSize = (IFX_uint32_t *)pMeiDev->meiERBbuf.pERB;
+   IFX_uint32_t *pMeiErrVecSize = (IFX_uint32_t *)pMeiDev->meiERBbuf.pERB_virt;
 #endif
 
    if (MEI_DRV_MEI_IF_STATE_GET(pMeiDev) == e_MEI_MEI_HW_STATE_UP)
@@ -2089,15 +2132,42 @@ IFX_int32_t MEI_ProcessIntPerIrq(MEIX_CNTRL_T *pMeiXCntrlList)
 {
    IFX_int32_t meiIntCnt = 0;
    MEIX_CNTRL_T *pNextXCntrl = pMeiXCntrlList;
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+   IFX_int_t   extraDbgStreamLoop = 0;
+#endif
 
    /* get the actual chip device from the list and step through the VRX devices */
    while(pNextXCntrl)
    {
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+      if (MEI_DBG_STREAMS_GLOBAL_CFG_DEV_STATE_GET(pNextXCntrl->entityNum) != 0)
+      {
+         extraDbgStreamLoop = 1;
+      }
+#endif
       meiIntCnt += MEI_ProcessIntPerChip(pNextXCntrl);
 
       pNextXCntrl = pNextXCntrl->pNextMeiXCntrl;
    }
 
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+   if (extraDbgStreamLoop == 1)
+   {
+      pNextXCntrl = pMeiXCntrlList;
+
+      while(pNextXCntrl)
+      {
+         if (MEI_DBG_STREAMS_GLOBAL_CFG_DEV_STATE_GET(pNextXCntrl->entityNum) != 0)
+         {
+            meiIntCnt += MEI_DBG_STREAMS_CAST(IFX_int32_t, MEI_ProcessIntPerChip(pNextXCntrl));
+         }
+
+         pNextXCntrl = pNextXCntrl->pNextMeiXCntrl;
+      }
+
+   }
+#endif
+
    return meiIntCnt;
 }
 
@@ -2451,7 +2521,7 @@ IFX_int32_t MEI_IoctlDevCfgFwModeSwap(
 #if 1
    MEI_DRV_GET_UNIQUE_DRIVER_ACCESS(pMeiDev);
 
-   /* set driver state "wait for first responce" */
+   /* set driver state "wait for first response" */
    MEI_DRV_STATE_SET(pMeiDev, e_MEI_DRV_STATE_WAIT_FOR_FIRST_RESP);
 
    MEI_DRV_RELEASE_UNIQUE_DRIVER_ACCESS(pMeiDev);
@@ -2464,11 +2534,11 @@ IFX_int32_t MEI_IoctlDevCfgFwModeSwap(
       return -e_MEI_ERR_OP_FAILED;
    }
 
-   /* wait for first responce */
+   /* wait for first response */
    if ( MEI_WaitForFirstResponce(pMeiDev) != IFX_SUCCESS)
    {
       PRN_ERR_USR_NL( MEI_DRV, MEI_DRV_PRN_LEVEL_ERR,
-             ("MEI_DRV[%02d]: SWAP FW failure - no responce!!!" MEI_DRV_CRLF,
+             ("MEI_DRV[%02d]: SWAP FW failure - no response!!!" MEI_DRV_CRLF,
              MEI_DRV_LINENUM_GET(pMeiDev)));
    }
 
@@ -2888,13 +2958,13 @@ IFX_int32_t MEI_IoctlPllOffsetConfigSet(
          ("MEI_DRV: PLL offset disabled" MEI_DRV_CRLF));
    }
 
-   else if ((pPllOffsetConfig->nPllOffset < MEI_PLL_OFFSET_MIN) ||
-       (pPllOffsetConfig->nPllOffset > MEI_PLL_OFFSET_MAX))
+   else if ((pPllOffsetConfig->nPllOffset < MEI_PLL_CLOCKSET_MIN) ||
+       (pPllOffsetConfig->nPllOffset > MEI_PLL_CLOCKSET_MAX))
    {
       PRN_ERR_USR_NL( MEI_DRV, MEI_DRV_PRN_LEVEL_ERR,
          ("MEI_DRV: PLL offset value %d out of range [%d..%d]"
           MEI_DRV_CRLF, pPllOffsetConfig->nPllOffset,
-          MEI_PLL_OFFSET_MIN, MEI_PLL_OFFSET_MAX));
+          MEI_PLL_CLOCKSET_MIN, MEI_PLL_CLOCKSET_MAX));
 
       return (-e_MEI_ERR_INVAL_CONFIG);
    }
@@ -2923,4 +2993,3 @@ IFX_int32_t MEI_IoctlPllOffsetConfigGet(
    pPllOffsetConfig->nPllOffset = pMeiDev->modemData.nPllOffset;
    return IFX_SUCCESS;
 }
-
