@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_CONFIG_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -45,6 +45,14 @@
 #  endif
 #endif
 
+#ifndef MEI_SUPPORT_DEVICE_VR10_320
+#  define MEI_SUPPORT_DEVICE_VR10_320      0
+#else
+#  if (MEI_SUPPORT_DEVICE_VR10_320 != 1)
+#     define MEI_SUPPORT_DEVICE_VR10_320   0
+#  endif
+#endif
+
 #ifndef MEI_SUPPORT_DEVICE_AR9
 #  define MEI_SUPPORT_DEVICE_AR9       0
 #else
@@ -54,15 +62,19 @@
 #endif
 
 #if (MEI_SUPPORT_DEVICE_VR9 == 1)
-#  if (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_AR9 == 1)
+#  if (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_VR10_320 == 1) || (MEI_SUPPORT_DEVICE_AR9 == 1)
      #error "Only one device can be selected!"
 #  endif
 #elif (MEI_SUPPORT_DEVICE_VR10 == 1)
-#  if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_AR9 == 1)
+#  if (MEI_SUPPORT_DEVICE_VR10_320 == 1) || (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_AR9 == 1)
+     #error "Only one device can be selected!"
+#  endif
+#elif (MEI_SUPPORT_DEVICE_VR10_320 == 1)
+#  if (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_AR9 == 1)
      #error "Only one device can be selected!"
 #  endif
 #elif (MEI_SUPPORT_DEVICE_AR9 == 1)
-#  if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1)
+#  if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
      #error "Only one device can be selected!"
 #  endif
 #else
@@ -152,7 +164,7 @@
 
 /** support interface to ATM/PTM drivers */
 #ifndef MEI_DRV_ATM_PTM_INTERFACE_ENABLE
-#  define MEI_DRV_ATM_PTM_INTERFACE_ENABLE    0
+#  define MEI_DRV_ATM_PTM_INTERFACE_ENABLE    1
 #else
 #  if ( (MEI_DRV_ATM_PTM_INTERFACE_ENABLE != 1) && (MEI_DRV_ATM_PTM_INTERFACE_ENABLE != 0) )
 #     undef  MEI_DRV_ATM_PTM_INTERFACE_ENABLE
@@ -201,7 +213,7 @@
 # endif
 #endif
 
-#if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1)
+#if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
    /** support Debug access (via General Purpose Access - msg's) */
    #ifndef MEI_SUPPORT_DFE_GPA_ACCESS
    #  define MEI_SUPPORT_DFE_GPA_ACCESS          1
@@ -346,8 +358,9 @@
 #  endif
 #endif
 
-#if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1)
-   #define INCLUDE_VR9_EMULATION_WORKAROUNDS
+/* exclude emulator option */
+#ifdef INCLUDE_VR9_EMULATION_WORKAROUNDS
+#undef INCLUDE_VR9_EMULATION_WORKAROUNDS
 #endif
 
 /* ==========================================================================
@@ -448,7 +461,7 @@
 
 /** get the number of of lines per device from extern */
 
-#if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1)
+#if (MEI_SUPPORT_DEVICE_VR9 == 1) || (MEI_SUPPORT_DEVICE_VR10 == 1) || (MEI_SUPPORT_DEVICE_VR10_320 == 1)
 #ifdef MEI_MAX_DFE_INSTANCE_PER_ENTITY
 #   if (MEI_MAX_DFE_INSTANCE_PER_ENTITY > 2)
 #      undef  MEI_MAX_DFE_INSTANCE_PER_ENTITY
@@ -524,5 +537,60 @@
 #  endif
 #endif
 
+#ifndef MEI_PREDEF_DBG_BAR
+#  define MEI_PREDEF_DBG_BAR    1
+#else
+#  if ( (MEI_PREDEF_DBG_BAR != 1) && (MEI_PREDEF_DBG_BAR != 0) )
+#     undef  MEI_PREDEF_DBG_BAR
+#     define MEI_PREDEF_DBG_BAR 1
+#     warning "switch on BAR debug user support - invalid config"
+#  endif
+#endif
+
+#ifndef MEI_SUPPORT_OPTIMIZED_FW_DL
+#  define MEI_SUPPORT_OPTIMIZED_FW_DL    1
+#else
+#  if ( (MEI_SUPPORT_OPTIMIZED_FW_DL != 1) && (MEI_SUPPORT_OPTIMIZED_FW_DL != 0) )
+#     undef  MEI_SUPPORT_OPTIMIZED_FW_DL
+#     define MEI_SUPPORT_OPTIMIZED_FW_DL 1
+#     warning "switch on optimised fw download - invalid config"
+#  endif
+#endif
+
+/** Debug Streams support */
+#ifndef MEI_SUPPORT_DEBUG_STREAMS
+#  define MEI_SUPPORT_DEBUG_STREAMS    1
+#else
+#  if ( (MEI_SUPPORT_DEBUG_STREAMS != 1) && (MEI_SUPPORT_DEBUG_STREAMS != 0) )
+#     undef  MEI_SUPPORT_DEBUG_STREAMS
+#     define MEI_SUPPORT_DEBUG_STREAMS 1
+#     warning "switch on debug stremas support - invalid config"
+#  endif
+#endif
+
+/** Debug Streams - support statistics. */
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+#  ifndef MEI_DBG_STREAMS_SUPPORT_STATISTICS
+#     define MEI_DBG_STREAMS_SUPPORT_STATISTICS              1
+#  endif
+#else
+#  ifdef MEI_DBG_STREAMS_SUPPORT_STATISTICS
+#     undef MEI_DBG_STREAMS_SUPPORT_STATISTICS
+#  endif
+#  define MEI_DBG_STREAMS_SUPPORT_STATISTICS                 0
+#endif
+
+/** Debug Logger support */
+#ifndef MEI_SUPPORT_DEBUG_LOGGER
+#  define MEI_SUPPORT_DEBUG_LOGGER    1
+#else
+#  if ( (MEI_SUPPORT_DEBUG_LOGGER != 1) && (MEI_SUPPORT_DEBUG_LOGGER != 0) )
+#     undef  MEI_SUPPORT_DEBUG_LOGGER
+#     define MEI_SUPPORT_DEBUG_LOGGER 1
+#     warning "switch on debug logger support - invalid config"
+#  endif
+#endif
+
+
 #endif      /* #ifndef _DRV_MEI_CPE_CONFIG_H */
 
