@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_DBG_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -241,6 +241,12 @@
 #endif
 */
 
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+#  define MEI_PRINT_INT_RAW (void) MEI_debugLogSend
+#  define MEI_PRINT_USR     (void) MEI_debugLogSend
+#  define MEI_PRINT_INT     (void) MEI_debugLogSend
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
+
 /**
    Debug printout - triggered from user call
 */
@@ -290,6 +296,7 @@
 #else
 
 #define PRN_DBG_USR_NL(module_name, dbg_level, print_message)
+#define PRN_DBG_USR_RAW(module_name, dbg_level, print_message)
 #define PRN_DBG_INT_NL(module_name, dbg_level, print_message)
 #define PRN_DBG_USR(module_name, dbg_level, line_num, print_message)
 #define PRN_DBG_INT(module_name, dbg_level, line_num, print_message)
