@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_ECOS_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -27,10 +27,6 @@
    typedefs interrupt wrapping (eCos)
    ========================================================================= */
 
-#ifndef KSEG1
-   #define KSEG1   (0x00000000)
-#endif
-
 #define MEI_DRVOS_SIGNAL_PENDING             0
 
 /**
