@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -430,6 +430,12 @@ IFX_void_t MEI_ShowStatusProc(FILE *streamOut)
                         MEIX_Cntrl[i]->MeiDevice[j]->statistics.fwDlErrCount);
 #endif
 
+#if (MEI_SUPPORT_OPTIMIZED_FW_DL == 1)
+               fprintf( streamOuts, "FwDownlOpt = %5d" MEI_DRV_CRLF,
+                              pMeiDev->statistics.fwDlOptSuccessCount);
+               fprintf( streamOuts, "FwDOptFail = %5d" MEI_DRV_CRLF,
+                              pMeiDev->statistics.fwDlOptFailedCount);
+#endif
                fprintf( streamOut, "TxMsg      = %5d\tRxAck       = %5d" MEI_DRV_CRLF,
                         MEIX_Cntrl[i]->MeiDevice[j]->statistics.sendMsgCount,
                         MEIX_Cntrl[i]->MeiDevice[j]->statistics.recvAckCount);
