@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_LINUX_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -33,9 +33,15 @@
 #include <linux/sched.h>
 #include <linux/interrupt.h>
 #include <linux/version.h>
+#include <linux/crc32.h>
+#include <linux/vmalloc.h>
 
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0))
-   #include <asm/ifx/irq.h>
+   #if (MEI_SUPPORT_DEVICE_VR10_320 != 1)
+      #include <asm/ifx/irq.h>
+   #else
+      #include <linux/irq.h>
+   #endif
 #else
    #include <irq.h>
    #include <net/net_namespace.h>
@@ -59,6 +65,12 @@
 
 #endif /* #if (MEI_DRV_IFXOS_ENABLE == 0)*/
 
+#include <linux/dma-mapping.h>
+#include <linux/dma-direction.h>
+#include <asm/dma-mapping.h>
+#include <linux/types.h>
+#include <linux/pci.h>
+
 /* ============================================================================
    typedefs interrupt wrapping (Linux)
    ========================================================================= */
@@ -85,10 +97,6 @@ typedef irqreturn_t (*usedIsrHandler_t)(int, void *, struct pt_regs *);
 typedef irqreturn_t (*usedIsrHandler_t)(int, void *);
 #endif
 
-#ifndef KSEG1
-   #define KSEG1   (0xa0000000)
-#endif
-
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0))
 #define MEI_DRVOS_SIGNAL_PENDING             0
 #else
@@ -134,7 +142,6 @@ typedef void (*MEI_IntEnable_WrapLinux_t)(int IRQNum);
 typedef void (*MEI_IntDisable_WrapLinux_t)(int IRQNum);
 
 
-
 /* ============================================================================
    global function (LINUX) - declarations
    ========================================================================= */
@@ -405,7 +412,7 @@ IFX_int32_t MEI_DRVOS_ThreadInit(
 /**
    LINUX Kernel - Shutdown and terminate a given thread.
    Therefore the thread delete functions triggers the user thread function
-   to shutdown. In case of not responce (timeout) the thread will be canceled.
+   to shutdown. In case of not response (timeout) the thread will be canceled.
 
 \par Implementation
    - force a shutdown via the shutdown flag and wait.
@@ -577,8 +584,13 @@ IFX_time_t MEI_DRVOS_ElapsedTimeMSecGet(
 #define MEI_DRVOS_CRLF                              "\n\r"
 
    /** Kernel - Error Print on Appl-Level (formated) */
-#define MEI_DRVOS_ERR_PRINT_USR(fmt, args...)       printk(fmt "\r", ##args)
-#define MEI_DRVOS_PRINT_INT_RAW(fmt, args...)       printk(fmt, ##args)
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+#  define MEI_DRVOS_ERR_PRINT_USR(fmt, args...) MEI_debugLogSend(fmt "\r", ##args)
+#  define MEI_DRVOS_PRINT_INT_RAW(fmt, args...) MEI_debugLogSend(fmt, ##args)
+#else
+#  define MEI_DRVOS_ERR_PRINT_USR(fmt, args...)       printk(fmt "\r", ##args)
+#  define MEI_DRVOS_PRINT_INT_RAW(fmt, args...)       printk(fmt, ##args)
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #define MEI_PRINT_USR                     MEI_DRVOS_ERR_PRINT_USR
 #define MEI_PRINT_INT                     MEI_DRVOS_ERR_PRINT_USR
@@ -606,6 +618,12 @@ IFX_time_t MEI_DRVOS_ElapsedTimeMSecGet(
 
 #endif /* #if (MEI_DRV_IFXOS_ENABLE == 0)*/
 
+#define MEI_DRVOS_DMA_Malloc(hwdev, size, ptr_phy) \
+               dma_alloc_coherent((hwdev), (size), (dma_addr_t *)(ptr_phy), GFP_ATOMIC)
+
+#define MEI_DRVOS_DMA_Free(hwdev, size, ptr_virt, ptr_phy) \
+               dma_free_coherent((hwdev), (size), (ptr_virt), (dma_addr_t)(ptr_phy))
+
 #endif   /* LINUX */
 #endif   /* _DRV_MEI_CPE_LINUX_H */
 
