@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -168,6 +168,13 @@ static void MEI_ProcReadConfigDTestCntrl(struct seq_file *s);
 static int MEI_ProcWriteConfigFsmSetPreAct(char *pArg);
 static void MEI_ProcReadConfigFsmSetPreAct(struct seq_file *s);
 
+static int MEI_ProcWriteConfigDebugFlags(char *pArg);
+static void MEI_ProcReadConfigDebugFlags(struct seq_file *s);
+
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+static int MEI_ProcWriteConfigDebugLogger(char *pArg);
+static void MEI_ProcReadConfigDebugLogger(struct seq_file *s);
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 
 /* ==========================================================================
@@ -823,6 +830,54 @@ static void MEI_ProcReadConfigMeiAccCse(struct seq_file *s)
 
 #endif      /* #if (MEI_EXT_MEI_ACCESS_ADD_CSE_MIPS == 1) || (MEI_EXT_MEI_ACCESS_ADD_CSE == 1) */
 
+/**
+   Handle procfs config - write MEI Debug Flags Mask.
+*/
+static int MEI_ProcWriteConfigDebugFlags(char *pArg)
+{
+   MEI_DbgFlags = MEI_GetDigitValue(pArg, 10);
+
+   return 0;
+}
+
+
+/**
+   Handle procfs config - read MEI Debug Flags Mask.
+*/
+static void MEI_ProcReadConfigDebugFlags(struct seq_file *s)
+{
+   seq_printf(s, "%2d: %s \t= %d" MEI_DRV_CRLF
+                 "\tBit0:  0: ARC HALT" MEI_DRV_CRLF
+                 "\tBit1..31: Reserved" MEI_DRV_CRLF,
+                 e_PROCFS_CONFIG_DBG_FLAGS,
+                 arrVrxDfeProcFsConfigTable[e_PROCFS_CONFIG_DBG_FLAGS].pName,
+                 MEI_DbgFlags);
+}
+
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+/**
+   Handle procfs config - write MEI Debug Flags Mask.
+*/
+static int MEI_ProcWriteConfigDebugLogger(char *pArg)
+{
+   MEI_DbgLogger = MEI_GetDigitValue(pArg, 10);
+
+   return 0;
+}
+
+/**
+   Handle procfs config - read MEI Debug Flags Mask.
+*/
+static void MEI_ProcReadConfigDebugLogger(struct seq_file *s)
+{
+   seq_printf(s, "%2d: %s \t= %d" MEI_DRV_CRLF
+                 "\t0: Logger is not used" MEI_DRV_CRLF
+                 "\t1: Logger is used" MEI_DRV_CRLF,
+                 e_PROCFS_CONFIG_DBG_LOGGER,
+                 arrVrxDfeProcFsConfigTable[e_PROCFS_CONFIG_DBG_LOGGER].pName,
+                 MEI_DbgLogger);
+}
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #if (MEI_SUPPORT_DRV_MODEM_TESTS == 1)
 /**
