@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_LINUX_PROC_CONFIG_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -173,6 +173,17 @@ extern "C"
 #define MEI_PROCFS_CONFIG_DTEST_CNTRL
 #endif
 
+#define MEI_PROCFS_CONFIG_DBG_FLAGS_ENTRY \
+            {"DBG_FLAGS", MEI_ProcReadConfigDebugFlags, MEI_ProcWriteConfigDebugFlags}
+#define MEI_PROCFS_CONFIG_DBG_FLAGS \
+            GET_FIELD_2(PROCFS_CONFIG_DBG_FLAGS, MEI_PROCFS_CONFIG_DBG_FLAGS_ENTRY, SEPARATOR)
+            
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
+#define MEI_PROCFS_CONFIG_DBG_LOGGER_ENTRY \
+            {"DBG_LOGGER", MEI_ProcReadConfigDebugLogger, MEI_ProcWriteConfigDebugLogger}
+#define MEI_PROCFS_CONFIG_DBG_LOGGER \
+            GET_FIELD_2(PROCFS_CONFIG_DBG_LOGGER, MEI_PROCFS_CONFIG_DBG_LOGGER_ENTRY, SEPARATOR)            
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 #define MEI_PROCFS_CONFIG_LAST_ENTRY \
             {"LAST", NULL, NULL}
@@ -189,6 +200,7 @@ extern "C"
 /* Test cases:
                         enum   | description | test function
 */
+#if (MEI_SUPPORT_DEBUG_LOGGER == 1)
 #define MEI_PROCFS_CONFIG_TABLE \
                      MEI_PROCFS_CONFIG_LOG \
                      MEI_PROCFS_CONFIG_TRACE \
@@ -213,8 +225,37 @@ extern "C"
                      MEI_PROCFS_CONFIG_MEI_ACCESS_ADD_CSE \
                      MEI_PROCFS_CONFIG_DTEST_CNTRL \
                      MEI_PROCFS_CONFIG_G_DBG_CONFIG \
+                     MEI_PROCFS_CONFIG_DBG_FLAGS \
+                     MEI_PROCFS_CONFIG_DBG_LOGGER \
                      MEI_PROCFS_CONFIG_LAST
-
+#else /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
+#define MEI_PROCFS_CONFIG_TABLE \
+                     MEI_PROCFS_CONFIG_LOG \
+                     MEI_PROCFS_CONFIG_TRACE \
+                     MEI_PROCFS_CONFIG_LOG_MEI \
+                     MEI_PROCFS_CONFIG_TRACE_MEI \
+                     MEI_PROCFS_CONFIG_TRACE_DL_ROM \
+                     MEI_PROCFS_CONFIG_MB_ME2ARC \
+                     MEI_PROCFS_CONFIG_MB_ARC2ME \
+                     MEI_PROCFS_CONFIG_RAM_DATA_WIDTH \
+                     MEI_PROCFS_CONFIG_WAITSTATES \
+                     MEI_PROCFS_CONFIG_MAX_WAIT_RDY_FOR_DL \
+                     MEI_PROCFS_CONFIG_MAX_WAIT_ACK_NEXT_BLOCK \
+                     MEI_PROCFS_CONFIG_MAX_WAIT_DL_START \
+                     MEI_PROCFS_CONFIG_BOOTMODE \
+                     MEI_PROCFS_CONFIG_BLOCK_TOUT \
+                     MEI_PROCFS_CONFIG_MAX_WAIT_MODEM_ONLINE\
+                     MEI_PROCFS_CONFIG_W_DFE_RESP \
+                     MEI_PROCFS_CONFIG_FW_SELECT \
+                     MEI_PROCFS_CONFIG_FSM_SET_PRE_ACT \
+                     MEI_PROCFS_CONFIG_MDMP_ENABLE \
+                     MEI_PROCFS_CONFIG_MDMP_ID \
+                     MEI_PROCFS_CONFIG_MEI_ACCESS_ADD_CSE \
+                     MEI_PROCFS_CONFIG_DTEST_CNTRL \
+                     MEI_PROCFS_CONFIG_G_DBG_CONFIG \
+                     MEI_PROCFS_CONFIG_DBG_FLAGS \
+                     MEI_PROCFS_CONFIG_LAST
+#endif /* (MEI_SUPPORT_DEBUG_LOGGER == 1) */
 
 /* specify no separator for the last table entry */
 #ifdef NO_SEPARATOR
