@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -43,11 +43,12 @@ static inline volatile IFX_uint32_t MEI_RCU_get(MEI_MEI_DRV_CNTRL_T *pMeiDrvCntr
    IFX_uint32_t ret = 0;
    if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR9))
    {
-      ret = (KSEG1 | 0x1F203000);
+      ret = (IFX_uint32_t)phys_to_virt(0x1F203000);
    }
-   else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+   else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+            MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
    {
-      ret = (KSEG1 | MEI_DRV_PCIE_PHY_MEMBASE_GET(pMeiDrvCntrl) | MEI_RCU_OFFSET);
+      ret = (MEI_DRV_PCIE_VIRT_MEMBASE_GET(pMeiDrvCntrl) | MEI_RCU_OFFSET);
    }
    return ret;
 }
@@ -57,7 +58,7 @@ static inline volatile IFX_uint32_t MEI_RCU_Slave_get(MEI_MEI_DRV_CNTRL_T *pMeiD
    IFX_uint32_t ret = 0;
    if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR9))
    {
-      ret = (KSEG1 | 0x19203000);
+      ret = (IFX_uint32_t)phys_to_virt(0x19203000);
    }
    return ret;
 }
@@ -610,7 +611,7 @@ IFX_int32_t MEI_ResetDfeBlocks(
    {
       PRN_DBG_USR_NL( MEI_MEI_ACCESS, MEI_DRV_PRN_LEVEL_NORMAL,
                  ("MEI[%02d]: MEI_ResetDfeBlocks - reset deactivation is not"
-                 " supported for VR9" MEI_DRV_CRLF,
+                 " supported for VRX" MEI_DRV_CRLF,
                  (IFX_uint32_t)pMeiDrvCntrl->dslLineNum));
    }
 #endif
@@ -967,8 +968,7 @@ IFX_uint32_t MEI_WriteDma16Bit( MEI_MEI_DRV_CNTRL_T *pMeiDrvCntrl,
 
       while (count < dataCount - (dataCount % 2))
       {
-         tmpRegValue = (((pTmpData[count] << 16) & 0xFFFF0000) | (pTmpData[count+1] & 0x0000FFFF));
-
+         tmpRegValue = MEI_LO_WORD_GET(pTmpData[count]) |  MEI_HI_WORD_GET(pTmpData[count+1]);
          tmpRegValue = SWAP32_DMA_WIDTH_ORDER(tmpRegValue);
 
          MEI_REG_ACCESS_ME_DX_DATA_SET(pMeiDrvCntrl, tmpRegValue);
@@ -979,8 +979,7 @@ IFX_uint32_t MEI_WriteDma16Bit( MEI_MEI_DRV_CNTRL_T *pMeiDrvCntrl,
       /* write unaligned block - last */
       if (count < dataCount)
       {
-         tmpRegValue = ((pTmpData[count++] << 16) & 0xFFFF0000);
-
+         tmpRegValue = MEI_LO_WORD_GET(pTmpData[count++]);
          tmpRegValue = SWAP32_DMA_WIDTH_ORDER(tmpRegValue);
 
          MEI_REG_ACCESS_ME_DX_DATA_SET(pMeiDrvCntrl, tmpRegValue);
@@ -1070,14 +1069,15 @@ IFX_uint32_t MEI_ReadDma16Bit(
 
       tmpRegValue = SWAP32_DMA_WIDTH_ORDER(tmpRegValue);
 
-      pData[count] = (tmpRegValue & 0xFFFF0000) >> 16;
+      pData[count] =  MEI_LSW_WORD_GET(tmpRegValue);
 
       count++;
 
       /* high word */
       if (count < dataCount)
       {
-         pData[count] = (tmpRegValue & 0x00000FFFF);
+         pData[count] = MEI_MSW_WORD_GET(tmpRegValue);;
+
          count++;
       }
    }
@@ -1119,7 +1119,7 @@ IFX_uint32_t MEI_GetDma(
 
       tmpRegValue = SWAP32_DMA_WIDTH_ORDER(tmpRegValue);
 
-      pData[count] = (tmpRegValue & 0xFFFF0000) >> 16;
+      pData[count] = MEI_LSW_WORD_GET(tmpRegValue);
 
 #if (TRACE_MEI_MEI_REG_ACCESS == 1)
       PRN_DBG_USR_NL( MEI_REG, MEI_DRV_PRN_LEVEL_NORMAL,
@@ -1131,7 +1131,7 @@ IFX_uint32_t MEI_GetDma(
       /* high word */
       if (count < dataCount)
       {
-         pData[count] = (tmpRegValue & 0x00000FFFF);
+      pData[count] = MEI_MSW_WORD_GET(tmpRegValue);
 
 #if (TRACE_MEI_MEI_REG_ACCESS == 1)
          PRN_DBG_USR_NL( MEI_REG, MEI_DRV_PRN_LEVEL_NORMAL,
@@ -1339,7 +1339,7 @@ IFX_uint16_t MEI_GetMailBoxCode(
    tmpRegVal = MEI_REG_ACCESS_ME_DX_DATA_GET(pMeiDrvCntrl);
 
    tmpRegVal = SWAP32_DMA_WIDTH_ORDER(tmpRegVal);
-   mbCode    = (tmpRegVal & 0xFFFF0000) >> 16;
+   mbCode = MEI_LSW_WORD_GET(tmpRegVal);
 
    /* return the mailbox code */
    return mbCode;
@@ -1561,7 +1561,8 @@ IFX_int32_t MEI_InterfaceDetect(
             return IFX_SUCCESS;
          }
       }
-      else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10))
+      else if (MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10) ||
+               MEI_DEVICE_CFG_IS_PLATFORM(e_MEI_DEV_PLATFORM_CONFIG_VR10_320))
       {
          if (hwVers == 0x00000240)
          {
