@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_MEI_INTERFACE_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -185,8 +185,8 @@ typedef struct mei_if_cntrl_s
 
 
 /**
-   VRX Rev 2 - device specific MEI Control struct (per device and per MEI 
-   Interface). 
+   VRX Rev 2 - device specific MEI Control struct (per device and per MEI
+   Interface).
 
    This struct contains the data for handling the MEI Interface per devcie
    - physical Address
