@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_MEI_VRX_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -44,6 +44,7 @@ extern "C"
    ========================================================================= */
 #define MEI_INTERNAL_ADDRESS_BASE   0x1E000000
 #define MEI_OUTBOUND_ADDRESS_BASE   0x20000000
+
 #define MEI_PDBRAM_OFFSET           0x80000
 #define MEI_RCU_OFFSET              0x2000
 #define MEI_DSL_MEI_OFFSET          0x116000
@@ -56,7 +57,7 @@ extern "C"
    Module      :  GPIO
    ========================================================================= */
 #define MEI_PCIE_PERIPHERIAL(mod_offset)  \
-(KSEG1 | MEI_DRV_PCIE_PHY_MEMBASE_GET(&pMeiDev->meiDrvCntrl) | (mod_offset))
+(MEI_DRV_PCIE_VIRT_MEMBASE_GET(&pMeiDev->meiDrvCntrl) | (mod_offset))
 #define PPE_SB_OFFSET                    0x12000
 #define PPE_SB_RAM_BLOCK_4_OFFSET        0x6000
 #define PPE_FORCE_LINK_DOWN              0x7DC1
@@ -399,49 +400,62 @@ typedef union
    IFX_vuint32_t       regRaw[sizeof(MEI_MEI_REG_IF_T)/sizeof(IFX_vuint32_t)];
 } MEI_MEI_REG_IF_U; /* old MEI_MEI_REGISTER_SET_T */
 
-#define MEI_PLL_OFFSET_MIN    -32768
-#define MEI_PLL_OFFSET_MAX    32767
-#define MEI_PLL_DISABLED      32768
 
-/** Message ID for CMD_PLL_OffsetSet (not in MCAT now)*/
-#define CMD_PLL_OFFSETSET 0x1962
+/* ************************************************************************** */
+/*                         CMD_PLL_CLOCKSET 0x1962                            */
+/* ************************************************************************** */
+
+#define MEI_PLL_CLOCKSET_MIN    -32768
+#define MEI_PLL_CLOCKSET_MAX     32767
+#define MEI_PLL_DISABLED         32768
+
+/** Message ID for CMD_PLL_ClockSet */
+#define CMD_PLL_CLOCKSET 0x1962
 
 /**
-   Set PLL offset value (only for VRX220)
+   Sets an offset for the PLL frequency compared to the crystals rated nominal
+   frequency of 36 MHz. This allows e.g. to finetune the handshake tone
+   frequencies to exactly match the standard values.
 */
-typedef struct CMD_PLL_OffsetSet CMD_PLL_OffsetSet_t;
+typedef struct CMD_PLL_ClockSet CMD_PLL_ClockSet_t;
 
-/** Message ID for ACK_PLL_OffsetSet (not in MCAT now) */
-#define ACK_PLL_OFFSETSET 0x1962
+/** Message ID for ACK_PLL_ClockSet */
+#define ACK_PLL_CLOCKSET 0x1962
 
 /**
-   Acknowledgement to CMD_PLL_OffsetSet
+   This is the acknowledgement for CMD_PLL_ClockSet.
 */
-typedef struct ACK_PLL_OffsetSet ACK_PLL_OffsetSet_t;
+typedef struct ACK_PLL_ClockSet ACK_PLL_ClockSet_t;
 
-struct CMD_PLL_OffsetSet
+/**
+   Sets an offset for the PLL frequency compared to the crystals rated nominal
+   frequency of 36 MHz. This allows e.g. to finetune the handshake tone
+   frequencies to exactly match the standard values.
+*/
+struct CMD_PLL_ClockSet
 {
 #if MEI_DRV_OS_BYTE_ORDER == MEI_DRV_OS_BIG_ENDIAN
    /** Index */
    IFX_uint16_t Index;
    /** Length */
    IFX_uint16_t Length;
-   /** PLL offset config */
-   IFX_uint16_t nPllOffset;
+   /** PLL Clock Offset in ppm */
+   IFX_int16_t pllClockOffset;
 #else
    /** Index */
    IFX_uint16_t Index;
    /** Length */
    IFX_uint16_t Length;
-   /** PLL offset config */
-   IFX_uint16_t nPllOffset;
+   /** PLL Clock Offset in ppm */
+   IFX_int16_t pllClockOffset;
 #endif
 } __PACKED__ ;
 
+
 /**
-   Acknowledgement to CMD_DSM_Control.
+   This is the acknowledgement for CMD_PLL_ClockSet.
 */
-struct ACK_PLL_OffsetSet
+struct ACK_PLL_ClockSet
 {
 #if MEI_DRV_OS_BYTE_ORDER == MEI_DRV_OS_BIG_ENDIAN
    /** Index */
@@ -456,6 +470,11 @@ struct ACK_PLL_OffsetSet
 #endif
 } __PACKED__ ;
 
+
+/* ************************************************************************** */
+/*                       CMD_MODEMFSM_STATEGET 0x0002                         */
+/* ************************************************************************** */
+
 /** Message ID for CMD_ModemFSM_StateGet */
 #define CMD_MODEMFSM_STATEGET 0x0002
 
@@ -522,6 +541,51 @@ struct ACK_ModemFSM_StateGet
 #endif
 } __PACKED__ ;
 
+/* ************************************************************************** */
+/*                       API TC-Layer re-definitions                          */
+/* ************************************************************************** */
+
+#define DSL_TC_ATM  1
+#define DSL_TC_EFM  2
+
+/* ************************************************************************** */
+/*                         EVT_TC_STATUSGET 0x0E22                            */
+/* ************************************************************************** */
+
+#define EVT_TC_StatusGet_EFM_TC 0x1
+#define EVT_TC_StatusGet_ATM_TC 0x2
+
+/** Message ID for EVT_TC_StatusGet */
+#define EVT_TC_STATUSGET 0x0E22
+
+/**
+   This autonomous Event reports the to be used TC mode after being known.
+*/
+typedef struct EVT_TC_StatusGet EVT_TC_StatusGet_t;
+
+/**
+   This autonomous Event reports the to be used TC mode after being known.
+*/
+struct EVT_TC_StatusGet
+{
+#if MEI_DRV_OS_BYTE_ORDER == MEI_DRV_OS_BIG_ENDIAN
+   /** Index */
+   IFX_uint16_t Index;
+   /** Length */
+   IFX_uint16_t Length;
+   /** TC Used */
+   IFX_uint16_t TC;
+#else
+   /** Index */
+   IFX_uint16_t Index;
+   /** Length */
+   IFX_uint16_t Length;
+   /** TC Used */
+   IFX_uint16_t TC;
+#endif
+} __PACKED__ ;
+
+
 #ifdef __cplusplus
 /* extern "C" */
 }
