@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_OS_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -34,6 +34,15 @@
 #include "ifxos_lock.h"
 #include "ifxos_time.h"
 #include "ifxos_select.h"
+#include "ifx_fifo.h"
+
+#if defined(IFXOS_HAVE_VERSION_CHECK)
+#  if (IFXOS_VERSION_CHECK_EG_THAN(1,1,0))
+#     define IFXOS_SUPPORTS_FIFO_PEEK                 1
+#  else
+#     define IFXOS_SUPPORTS_FIFO_PEEK                 0
+#  endif
+#endif
 
 #endif /* #if (MEI_DRV_IFXOS_ENABLE == 1)*/
 
@@ -62,12 +71,6 @@
 #  error "OS type not defined!!!"
 #endif
 
-#if defined(LINUX)
-#define MEI_DRVOS_NON_CACHED_MEM_ADDR(x)   KSEG1ADDR(x)
-#else
-#define MEI_DRVOS_NON_CACHED_MEM_ADDR(x)   (x)
-#endif /* #if defined(LINUX)*/
-
 #if (MEI_DRV_IFXOS_ENABLE == 1)
 
 #if defined(IFXOS_HAVE_VERSION_CHECK)
@@ -108,9 +111,11 @@
 #define MEI_DRVOS_EventWakeUp             IFXOS_EventWakeUp
 #define MEI_DRVOS_EventWait_timeout(_event_, _time_to_wait_) IFXOS_EventWait(_event_, _time_to_wait_, IFX_NULL)
 
-#define MEI_PRINT_USR                     IFXOS_DBG_PRINT_USR
-#define MEI_PRINT_INT                     IFXOS_ERR_PRINT_INT
-#define MEI_PRINT_INT_RAW                 IFXOS_PRINT_INT_RAW
+#if (MEI_SUPPORT_DEBUG_LOGGER != 1)
+#  define MEI_PRINT_USR                   IFXOS_DBG_PRINT_USR
+#  define MEI_PRINT_INT                   IFXOS_ERR_PRINT_INT
+#  define MEI_PRINT_INT_RAW               IFXOS_PRINT_INT_RAW
+#endif /* !defined(MEI_SUPPORT_DEBUG_LOGGER) */
 
 #define MEI_DRVOS_GetElapsedTime_ms       IFXOS_ElapsedTimeMSecGet
 #define MEI_DRVOS_Wait_ms                 IFXOS_MSecSleep
@@ -133,6 +138,13 @@
 #define MEI_DRVOS_CpyToUser               IFXOS_CpyToUser
 #define MEI_DRVOS_CpyFromUser             IFXOS_CpyFromUser
 
+#define MEI_DRVOS_VFIFO                   IFX_VFIFO
+#define MEI_DRVOS_Var_Fifo_Init           IFX_Var_Fifo_Init
+#define MEI_DRVOS_Var_Fifo_Clear          IFX_Var_Fifo_Clear
+#define MEI_DRVOS_Var_Fifo_readElement    IFX_Var_Fifo_readElement
+#define MEI_DRVOS_Var_Fifo_peekElement    IFX_Var_Fifo_peekElement
+#define MEI_DRVOS_Var_Fifo_writeElement   IFX_Var_Fifo_writeElement
+#define MEI_DRVOS_Var_Fifo_getCount       IFX_Var_Fifo_getCount 
 
 #define MEI_DRV_OS_LITTLE_ENDIAN          IFXOS_LITTLE_ENDIAN
 #define MEI_DRV_OS_BIG_ENDIAN             IFXOS_BIG_ENDIAN
@@ -143,6 +155,30 @@
 #define MEI_DRVOS_DEFAULT_STACK_SIZE      IFXOS_DEFAULT_STACK_SIZE
 #endif
 
+#else /* #if (MEI_DRV_IFXOS_ENABLE == 1)*/
+#if (MEI_SUPPORT_DEBUG_STREAMS == 1)
+/**
+   MEI_DRVOS_VFIFO data structure
+*/
+typedef struct
+{
+   /** start pointer of IFX_FIFO buffer */
+   IFX_ulong_t* pStart;
+   /** end pointer of IFX_FIFO buffer */
+   IFX_ulong_t* pEnd;
+   /** read pointer of IFX_FIFO buffer */
+   IFX_ulong_t* pRead;
+   /** write pointer of IFX_FIFO buffer */
+   IFX_ulong_t* pWrite;
+   /** element size */
+   IFX_ulong_t size;
+   /** element count, changed on read and write: */
+   IFX_vuint32_t count;
+   /** maximum of IFX_FIFO elements (or maximum element size of IFX_VFIFO)*/
+   IFX_uint32_t max_size;
+} MEI_DRVOS_VFIFO;
+
+#endif /* (MEI_SUPPORT_DEBUG_STREAMS == 1) */
 #endif /* #if (MEI_DRV_IFXOS_ENABLE == 1)*/
 
 #endif      /* #ifndef _DRV_MEI_CPE_OS_H */
