@@ -2,8 +2,8 @@
 #define _drv_MEI_CPE_rom_handler_h
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -69,9 +69,9 @@ extern "C"
 /** Boot from ROM and download from Host via DMA and CodeSwap */
 #define MEI_DEV_BOOT_MODE_FWDL_ROM_DMA_CS        0x07
 
-/** Boot from ROM and download from Hosts FLASH into on-chip SRAM */
+/** Boot from ROM and download from Host's FLASH into on-chip SRAM */
 #define MEI_DEV_BOOT_MODE_FWDL_ROM_START_SRAM    0x08
-/** Boot from ROM and download from Hosts FLASH into external SRAM */
+/** Boot from ROM and download from Host's FLASH into external SRAM */
 #define MEI_DEV_BOOT_MODE_FWDL_ROM_START_EXT_RAM 0x09
 
 
