@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -1465,7 +1465,7 @@ int MEI_DevCreate(void)
    IFX_int32_t       ret = IFX_SUCCESS;
 
    printf("%s", &MEI_WHATVERSION[4]);
-   printf(", (c) 2013 Lantiq Deutschland GmbH" MEI_DRV_CRLF);
+   printf(", (c) 2007-2015 Lantiq Beteiligungs-GmbH & Co. KG" MEI_DRV_CRLF);
 
    MEI_DRV_PRN_USR_LEVEL_SET(MEI_DRV, MEI_DRV_PRN_LEVEL_HIGH);
    MEI_DRV_PRN_INT_LEVEL_SET(MEI_DRV, MEI_DRV_PRN_LEVEL_HIGH);
