@@ -2,8 +2,8 @@
 #define _DRV_MEI_CPE_VXWORKS_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -26,10 +26,6 @@
 #include <vxworks.h>
 #include "intLib.h"
 
-#ifndef KSEG1
-   #define KSEG1   (0x00000000)
-#endif
-
 /* ============================================================================
    typedefs interrupt wrapping (vxWorks)
    ========================================================================= */
