@@ -2,8 +2,8 @@
 #define _MEI_CPE_APPL_OSMAP_H
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -34,6 +34,7 @@ extern "C"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <errno.h>
 #include <ctype.h>
 #include <sys/ioctl.h>
@@ -48,6 +49,7 @@ extern "C"
 #define MEIOS_StrNCpy                  strncpy
 #define MEIOS_StrLen                   strlen
 #define MEIOS_StrError                 strerror
+#define MEIOS_StrCaseCmp               strncasecmp
 #define MEIOS_PError                   perror
 #define MEIOS_StrToUl                  strtoul
 #define MEIOS_Printf                   printf
