@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -38,6 +38,21 @@
 /* Local Variables                                                */
 /* ============================================================== */
 
+#if (MEI_SUPPORT_DEVICE_VR10_320 == 1)
+/* Dummy functions to avoid linker complaints */
+void __aeabi_unwind_cpp_pr0(void)
+{
+};
+
+void __aeabi_unwind_cpp_pr1(void)
+{
+};
+
+void __aeabi_unwind_cpp_pr2(void)
+{
+};
+#endif
+
 
 /* ============================================================== */
 /* Local Function Declaration                                     */
@@ -219,7 +234,7 @@ static char description[][64] =
 /* 20 */   {"mei dbg access read  (-M <adr> -D <dest> -x <cnt>)"},
 /* 21 */   {"mei dbg access destination AUX=0, LDST=2, CORE=3"},
 /* 22 */   {"Drv Reset -R <MMMMRRRR> (RstMask:MMMM,RstMode:RRRR)"},
-/* 23 */   {"FW Download [-o <0/1>] firmware<#>.bin) [-z <name>]"},
+/* 23 */   {"FW Download [-o <0/1>] firmware<#>.bin) [-z <name>/<null>]"},
 /* 24 */   {"FW Swap -f <mode> (0: VDSL2, 1: ADSL)"},
 /* 25 */   {"Set mode (xdsl<0/1>, id<5/7>, fw_xdsl<0|1|2|4|8>) [-z <...>]"},
 /* 26 */   {"Set BusMaster -C <chipId> -0 <MEI sel mask>"},
@@ -237,18 +252,18 @@ static char description[][64] =
 /* 38 */   {"Get DSM statistic (processed, dropped)"},
 /* 39 */   {"Get MAC address (XX:XX:XX:XX:XX:XX)"},
 /* 40 */   {"Set MAC address (XX:XX:XX:XX:XX:XX) [-z <address>]"},
-/* 41 */   {"Set debug level (module <1/2>, level <1/2/3/4>) -z <...>"},
+/* 41 */   {"Set debug level (module <1/2/3>, level <1/2/3/4>) -z <...>"},
 /* 42 */   {"set PLL offset (dec) [-32768..32767], 32768 (ignore PLL)"},
 /* 43 */   {"get PLL offset (dec)"},
-/*    */   {"message param 0"},
-/*    */   {"message param 1"},
-/*    */   {"message param 2"},
-/*    */   {"message param 3"},
-/*    */   {"message param 4"},
-/*    */   {"message param 5"},
-/*    */   {"message param 6"},
-/*    */   {"message param 7"},
-/*    */   {"arg string z"},
+/* 44 */   {"message param 0"},
+/* 45 */   {"message param 1"},
+/* 46 */   {"message param 2"},
+/* 47 */   {"message param 3"},
+/* 48 */   {"message param 4"},
+/* 49 */   {"message param 5"},
+/* 50 */   {"message param 6"},
+/* 51 */   {"message param 7"},
+/* 52 */   {"arg string z"},
            {0}
 };
 
@@ -902,7 +917,7 @@ static void parseArgs(int argc, char *argv[])
          case 'z':
             GetOptArg_RequStr(optarg, &argStrParam[0][0], "opt Str[0]");
             break;
-
+            
       }        /* switch(c) {...} */
    }        /* while(1) {...} */
 
@@ -1043,7 +1058,7 @@ int main(int argc, char *argv[])
 
 void MEI_drv_test(void)
 {
-   int fd, ret=-1;
+   int fd, ret=-1;   
    MEIOS_File_t *streamOut = stdout;
 
    /* open default device or given device num */
@@ -1313,7 +1328,7 @@ void MEI_drv_test(void)
    {
       ret = MEI_pll_offset_set(streamOut, fd, bPllOffsetSet);
    }
-
+   
    /* == END Test cases ==================================================== */
    /*
    MEIOS_Printf(TEST_MEI_DBG_PREFIX"close(%d) device: /%s/%s/%d." MEIOS_CRLF, fd,
