@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -55,7 +55,6 @@
 /* get the CMV message format */
 #include "cmv_message_format.h"
 
-
 /* ==========================================================================
    Macros
    ========================================================================== */
@@ -1554,27 +1553,37 @@ int MEI_fw_download_name(MEIOS_File_t *streamOut, int fd, char *pFileName)
 {
    IFX_size_t filesize = 0;
 
-   if (MEIOS_FileLoad (pFileName, &pVrxFileBuffer, &filesize) != 0)
+   if ((MEIOS_StrCaseCmp(pFileName, "null", MEIOS_StrLen("null")) == 0))
    {
-      MEIOS_FPrintf(streamOut, TEST_MEI_DBG_PREFIX
-               "ERROR: FW Download - load FW image file <%s> failed", pFileName);
-      return -1;
+         MEIOS_Printf( TEST_MEI_DBG_PREFIX
+                 "No fw binary (expected chunks reuse)" MEIOS_CRLF);
+         MEI_FwDl.pFwImage = NULL;
+         MEI_FwDl.size_byte = 0;
    }
-
-   /* Open file for input: */
-   if(filesize <= 0)
+   else
    {
-      MEIOS_FPrintf(streamOut, TEST_MEI_DBG_PREFIX
-               "ERROR: FW Download - load FW image file <%s> failed (size)", pFileName);
-      return -1;
+      if (MEIOS_FileLoad (pFileName, &pVrxFileBuffer, &filesize) != 0)
+      {
+         MEIOS_FPrintf(streamOut, TEST_MEI_DBG_PREFIX
+                  "ERROR: FW Download - load FW image file <%s> failed", pFileName);
+         return -1;
+      }
+
+      /* Open file for input: */
+      if(filesize <= 0)
+      {
+         MEIOS_FPrintf(streamOut, TEST_MEI_DBG_PREFIX
+                  "ERROR: FW Download - load FW image file <%s> failed (size)", pFileName);
+         return -1;
+      }
+
+      MEIOS_Printf( TEST_MEI_DBG_PREFIX
+              "Start Download <%s>, size: %lu" MEIOS_CRLF, pFileName, filesize);
+
+      MEI_FwDl.pFwImage = pVrxFileBuffer;
+      MEI_FwDl.size_byte = (IFX_uint32_t)filesize;
    }
 
-   MEIOS_Printf( TEST_MEI_DBG_PREFIX
-           "Start Download <%s>, size: %lu" MEIOS_CRLF, pFileName, filesize);
-
-   MEI_FwDl.pFwImage = pVrxFileBuffer;
-   MEI_FwDl.size_byte = (IFX_uint32_t)filesize;
-
    if ( (MEIOS_DeviceControl(fd, FIO_MEI_FW_DL, (MEI_IOCTL_ARG)&MEI_FwDl)) < 0 )
    {
       MEIOS_FPrintf(streamOut, TEST_MEI_DBG_PREFIX
@@ -2121,7 +2130,7 @@ int MEI_mac_set(MEIOS_File_t *streamOut, int fd, char *pMAC)
 int MEI_dbg_lvl_set(MEIOS_File_t *streamOut, int fd, char *pConfig)
 {
    IOCTL_MEI_dbgLevel_t dbg_lvl;
-   char* dbg_module[2] = {"MEI_DRV", "MEI_MSG_DUMP_API"};
+   char* dbg_module[3] = {"MEI_DRV", "MEI_MSG_DUMP_API", "MEI_NOTIFICATIONS"};
    char* dbg_level[4] = {"LOW", "NORMAL", "HIGH", "OFF"};
 
    memset(&dbg_lvl, 0x0, sizeof(IOCTL_MEI_dbgLevel_t));
