@@ -2,8 +2,8 @@
 #define _MEI_CPE_drv_test_fct_h
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -159,6 +159,8 @@ int MEI_dsm_statistics_get(MEIOS_File_t *streamOut, int fd);
 int MEI_mac_get(MEIOS_File_t *streamOut, int fd);
 int MEI_mac_set(MEIOS_File_t *streamOut, int fd, char *pMAC);
 int MEI_dbg_lvl_set(MEIOS_File_t *streamOut, int fd, char *pConfig);
+int MEI_pll_offset_get(MEIOS_File_t *streamOut, int fd);
+int MEI_pll_offset_set(MEIOS_File_t *streamOut, int fd, int pll_offset);
 
 #ifdef LINUX
 int MEI_nfc_wait_for_nfcs(MEIOS_File_t *streamOut, int max_wait_count, int dfeNum, int *pParams);
