@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -153,7 +153,7 @@ static int __init MEI_TEST_module_init (void)
    int result;
 
    printk(KERN_INFO "%s", &MEI_TEST_DRV_WHAT_STR[4]);
-   printk(KERN_INFO ", (c) 2013 Lantiq Deutschland GmbH" MEI_DRV_CRLF);
+   printk(KERN_INFO ", (c) 2007-2015 Lantiq Beteiligungs-GmbH & Co. KG" MEI_DRV_CRLF);
 
    MEI_DRV_PRN_USR_LEVEL_SET(MEI_TEST, debug_level);
    MEI_DRV_PRN_INT_LEVEL_SET(MEI_TEST, debug_level);
